@@ -1,4 +1,4 @@
-/* $ID: image.c, last updated 2020-06-15, F.Osorio */
+/* $ID: image.c, last updated 2022-08-18, F.Osorio */
 
 #include "base.h"
 #include "spatialpack.h"
@@ -14,7 +14,7 @@ static double lightness(double, double, double);
 static double luma(double, double, double);
 static double rmy(double, double, double);
 static double weighted(double, double, double, double *);
-static void grayscale(double *, int, double *, double *, double *, int, int, double *, method);
+static void grayscale(double *, double *, double *, double *, int, double *, method);
 /* ..end declarations */
 
 static double
@@ -69,53 +69,57 @@ weighted(double red, double green, double blue, double *wts) {
 }
 
 static void
-grayscale(double *y, int ldy, double *red, double *green, double *blue, int ncol,
-  int nrow, double *weights, method job)
+grayscale(double *y, double *red, double *green, double *blue, int nobs, double *weights,
+  method job)
 { /* grayscale method dispatcher */
-  for (int j = 0; j < ncol; j++) {
-    for (int i = 0; i < nrow; i++) {
-      switch (job) {
-        case AVERAGE:
-          y[i] = average(red[i], green[i], blue[i]);
-          break;
-        case BT240:
-          y[i] = BT_240(red[i], green[i], blue[i]);
-          break;
-        case BRIGHTER:
-          y[i] = brighter(red[i], green[i], blue[i]);
-          break;
-        case DARKER:
-          y[i] = darker(red[i], green[i], blue[i]);
-          break;
-        case ITU:
-          y[i] = BT_709(red[i], green[i], blue[i]);
-          break;
-        case LIGHTNESS:
-          y[i] = lightness(red[i], green[i], blue[i]);
-          break;
-        case LUMA:
-          y[i] = luma(red[i], green[i], blue[i]);
-          break;
-        case RMY:
-          y[i] = rmy(red[i], green[i], blue[i]);
-          break;
-        case WEIGHTED:
-          y[i] = weighted(red[i], green[i], blue[i], weights);
-          break;
-      }
-    }
-    y += ldy; red += ldy; green += ldy; blue += ldy;
+  switch (job) {
+    case AVERAGE:
+      for (int i = 0; i < nobs; i++)
+        y[i] = average(red[i], green[i], blue[i]);
+      break;
+    case BT240:
+      for (int i = 0; i < nobs; i++)
+        y[i] = BT_240(red[i], green[i], blue[i]);
+      break;
+    case BRIGHTER:
+      for (int i = 0; i < nobs; i++)
+        y[i] = brighter(red[i], green[i], blue[i]);
+      break;
+    case DARKER:
+      for (int i = 0; i < nobs; i++)
+        y[i] = darker(red[i], green[i], blue[i]);
+      break;
+    case ITU:
+      for (int i = 0; i < nobs; i++)
+        y[i] = BT_709(red[i], green[i], blue[i]);
+      break;
+    case LIGHTNESS:
+      for (int i = 0; i < nobs; i++)
+        y[i] = lightness(red[i], green[i], blue[i]);
+      break;
+    case LUMA:
+      for (int i = 0; i < nobs; i++)
+        y[i] = luma(red[i], green[i], blue[i]);
+      break;
+    case RMY:
+      for (int i = 0; i < nobs; i++)
+        y[i] = rmy(red[i], green[i], blue[i]);
+      break;
+    case WEIGHTED:
+      for (int i = 0; i < nobs; i++)
+        y[i] = weighted(red[i], green[i], blue[i], weights);
+      break;
   }
 }
 
 void
-RGB2gray_img(double *y, int *ny, double *red, double *green, double *blue, int *nr, int *nc,
-  double *weights, int *task)
+RGB2gray_img(double *y, double *red, double *green, double *blue, int *nobs, double *weights,
+  int *task)
 { /* convert an image in RGB channels into a graycale */
-  int ldy = *ny, nrow = *nr, ncol = *nc;
+  int n = *nobs;
   method job = *task;
 
-  grayscale(y, ldy, red, green, blue, nrow, ncol, weights, job);
+  grayscale(y, red, green, blue, n, weights, job);
 }
 
 void
@@ -219,19 +223,3 @@ gamma_noise(double *y, int *ny, int *nr, int *nc, double *looks)
   }
   PutRNGstate();
 }
-
-void
-sqrt_gamma_noise(double *y, int *ny, int *nr, int *nc, double *looks)
-{ /* add multiplicative (square root of Gamma) noise to 'y' matrix */
-  int ldy = *ny, nrow = *nr, ncol = *nc;
-  double nlooks = *looks;
-
-  GetRNGstate();
-  for (int j = 0; j < ncol; j++) {
-    for (int i = 0; i < nrow; i++) {
-      y[i] *= rng_sqrt_gamma(nlooks, nlooks);
-    }
-    y += ldy;
-  }
-  PutRNGstate();
-}
